#ifndef _ASTERISK_CHAN_SIP_H
#define _ASTERISK_CHAN_SIP_H

#define SIP_DTMF_RFC2833   (1 << 0)
#define SIP_DTMF_INBAND    (1 << 1)
#define SIP_DTMF_INFO      (1 << 2)

#define SIP_TYPE_USER   (1 << 0)
#define SIP_TYPE_PEER   (1 << 1)
#define SIP_TYPE_FRIEND (SIP_TYPE_USER|SIP_TYPE_PEER)

#define REINVITE_INVITE    1
#define REINVITE_UPDATE    2

struct sip_user {
	/* Users who can access various contexts */
	char name[80];
	char secret[80];
	char md5secret[80];
	char context[80];
	char callerid[80];
	char methods[80];
	char accountcode[20];
	char language[MAX_LANGUAGE];
	unsigned int callgroup;
	unsigned int pickupgroup;
	int nat;
	int hascallerid;
	int amaflags;
	int insecure;
	int canreinvite;
	int capability;
	int dtmfmode;
	int inUse;
	int incominglimit;
	int outUse;
	int outgoinglimit;
	int restrictcid;
	struct ast_ha *ha;
	int   temponly;
	struct sip_user *next;
};

struct sip_peer {
	char name[80];
	char secret[80];
	char md5secret[80];
	char context[80];    /* JK02: peers need context too to allow parking etc */
	char methods[80];
	char username[80];
	char tohost[80];
	char fromuser[80];
	char fromdomain[80];
	char mailbox[AST_MAX_EXTENSION];
	int lastmsgssent;
	time_t   lastmsgcheck;
	int dynamic;
	int expire;
	int expiry;
	int capability;
	int insecure;
	int nat;
	int canreinvite;
	unsigned int callgroup;
	unsigned int pickupgroup;
	int dtmfmode;
	struct sockaddr_in addr;
	struct in_addr mask;
	
	/* Qualification */
	struct sip_pvt *call;      /* Call pointer */
	int pokeexpire;            /* When to expire poke */
	int lastms;             /* How long last response took (in ms), or -1 for no response */
	int maxms;              /* Max ms we will accept for the host to be up, 0 to not monitor */
	struct timeval ps;         /* Ping send time */
	
	struct sockaddr_in defaddr;
	struct ast_ha *ha;
	int delme;
	int selfdestruct;
	int lastmsg;
	int temponly;
	struct sip_peer *next;
};
	
#endif
